==> kdp-api-python-client-4.50.0.tar.gz: kdp-api-python-client-4.50.0/kdp_api/models/__init__.py <==
# flake8: noqa

# import all models into this package
# if you have many models here with many references from one model to another this may
# raise a RecursionError
# to avoid this, import only the models that you directly need like:
# from from kdp_api.model.pet import Pet
# or import this package, but before doing it, use:
# import sys
# sys.setrecursionlimit(n)

from kdp_api.model.abac_label_parser_paginator import AbacLabelParserPaginator
from kdp_api.model.abac_label_parsers import AbacLabelParsers
from kdp_api.model.abac_label_parsers_list import AbacLabelParsersList
from kdp_api.model.api_error import ApiError
from kdp_api.model.application import Application
from kdp_api.model.application_create_request import ApplicationCreateRequest
from kdp_api.model.application_list import ApplicationList
from kdp_api.model.application_paginator import ApplicationPaginator
from kdp_api.model.application_patch_request import ApplicationPatchRequest
from kdp_api.model.application_required_dataset_access import ApplicationRequiredDatasetAccess
from kdp_api.model.application_update_request import ApplicationUpdateRequest
from kdp_api.model.applications_required_dataset_access import ApplicationsRequiredDatasetAccess
from kdp_api.model.attribute import Attribute
from kdp_api.model.attribute_assignment import AttributeAssignment
from kdp_api.model.attribute_assignment_create_request import AttributeAssignmentCreateRequest
from kdp_api.model.attribute_assignment_list import AttributeAssignmentList
from kdp_api.model.attribute_assignment_paginator import AttributeAssignmentPaginator
from kdp_api.model.attribute_assignment_patch_request import AttributeAssignmentPatchRequest
from kdp_api.model.attribute_assignment_update_request import AttributeAssignmentUpdateRequest
from kdp_api.model.attribute_create_request import AttributeCreateRequest
from kdp_api.model.attribute_list import AttributeList
from kdp_api.model.attribute_paginator import AttributePaginator
from kdp_api.model.attribute_patch_request import AttributePatchRequest
from kdp_api.model.attribute_update_request import AttributeUpdateRequest
from kdp_api.model.audit_log_configuration import AuditLogConfiguration
from kdp_api.model.audit_log_configuration_list import AuditLogConfigurationList
from kdp_api.model.audit_log_configuration_paginator import AuditLogConfigurationPaginator
from kdp_api.model.audit_log_event import AuditLogEvent
from kdp_api.model.audit_log_event_list import AuditLogEventList
from kdp_api.model.audit_log_paginator import AuditLogPaginator
from kdp_api.model.authentication import Authentication
from kdp_api.model.authentication_details import AuthenticationDetails
from kdp_api.model.authentication_details_authentication import AuthenticationDetailsAuthentication
from kdp_api.model.authentication_details_authentication_payload import AuthenticationDetailsAuthenticationPayload
from kdp_api.model.authentication_details_user import AuthenticationDetailsUser
from kdp_api.model.authentication_list import AuthenticationList
from kdp_api.model.batch_write_request import BatchWriteRequest
from kdp_api.model.data_source_params import DataSourceParams
from kdp_api.model.dataset import Dataset
from kdp_api.model.dataset_create_request import DatasetCreateRequest
from kdp_api.model.dataset_current_user_permissions import DatasetCurrentUserPermissions
from kdp_api.model.dataset_list import DatasetList
from kdp_api.model.dataset_paginator import DatasetPaginator
from kdp_api.model.dataset_patch_request import DatasetPatchRequest
from kdp_api.model.dataset_permission import DatasetPermission
from kdp_api.model.dataset_permission_create_request import DatasetPermissionCreateRequest
from kdp_api.model.dataset_permission_list import DatasetPermissionList
from kdp_api.model.dataset_permission_paginator import DatasetPermissionPaginator
from kdp_api.model.dataset_permission_patch_request import DatasetPermissionPatchRequest
from kdp_api.model.dataset_permission_update_request import DatasetPermissionUpdateRequest
from kdp_api.model.dataset_update_request import DatasetUpdateRequest
from kdp_api.model.error_code import ErrorCode
from kdp_api.model.group import Group
from kdp_api.model.group_create_request import GroupCreateRequest
from kdp_api.model.group_list import GroupList
from kdp_api.model.group_membership import GroupMembership
from kdp_api.model.group_membership_create_request import GroupMembershipCreateRequest
from kdp_api.model.group_membership_list import GroupMembershipList
from kdp_api.model.group_membership_paginator import GroupMembershipPaginator
from kdp_api.model.group_membership_patch_request import GroupMembershipPatchRequest
from kdp_api.model.group_membership_update_request import GroupMembershipUpdateRequest
from kdp_api.model.group_paginator import GroupPaginator
from kdp_api.model.group_patch_request import GroupPatchRequest
from kdp_api.model.group_update_request import GroupUpdateRequest
from kdp_api.model.index import Index
from kdp_api.model.index_list import IndexList
from kdp_api.model.index_paginator import IndexPaginator
from kdp_api.model.ingest_create_request import IngestCreateRequest
from kdp_api.model.job import Job
from kdp_api.model.job_list import JobList
from kdp_api.model.job_paginator import JobPaginator
from kdp_api.model.json_record import JsonRecord
from kdp_api.model.koverse_document_metadata import KoverseDocumentMetadata
from kdp_api.model.lucene_query_request import LuceneQueryRequest
from kdp_api.model.query import Query
from kdp_api.model.query_datasets_summary import QueryDatasetsSummary
from kdp_api.model.query_datasets_summary_datasets import QueryDatasetsSummaryDatasets
from kdp_api.model.query_datasets_summary_request import QueryDatasetsSummaryRequest
from kdp_api.model.query_document_lucene_request import QueryDocumentLuceneRequest
from kdp_api.model.query_document_lucene_response import QueryDocumentLuceneResponse
from kdp_api.model.query_document_lucene_response_records import QueryDocumentLuceneResponseRecords
from kdp_api.model.read_range_request import ReadRangeRequest
from kdp_api.model.record_batch import RecordBatch
from kdp_api.model.reindex_request import ReindexRequest
from kdp_api.model.security_label_info_params import SecurityLabelInfoParams
from kdp_api.model.segment import Segment
from kdp_api.model.segment_list import SegmentList
from kdp_api.model.segment_paginator import SegmentPaginator
from kdp_api.model.sequence_read_request import SequenceReadRequest
from kdp_api.model.source_types import SourceTypes
from kdp_api.model.source_types_list import SourceTypesList
from kdp_api.model.split_points import SplitPoints
from kdp_api.model.stripe_latest_charge import StripeLatestCharge
from kdp_api.model.stripe_latest_charge1 import StripeLatestCharge1
from kdp_api.model.transfer_resource_request import TransferResourceRequest
from kdp_api.model.transfer_resource_request_list import TransferResourceRequestList
from kdp_api.model.user import User
from kdp_api.model.user_create_request import UserCreateRequest
from kdp_api.model.user_list import UserList
from kdp_api.model.user_paginator import UserPaginator
from kdp_api.model.user_patch_request import UserPatchRequest
from kdp_api.model.user_update_request import UserUpdateRequest
from kdp_api.model.workspace import Workspace
from kdp_api.model.workspace_create_request import WorkspaceCreateRequest
from kdp_api.model.workspace_list import WorkspaceList
from kdp_api.model.workspace_paginator import WorkspacePaginator
from kdp_api.model.workspace_patch_request import WorkspacePatchRequest
from kdp_api.model.workspace_subscription import WorkspaceSubscription
from kdp_api.model.workspace_subscription_subscription_item_ids import WorkspaceSubscriptionSubscriptionItemIds
from kdp_api.model.workspace_update_request import WorkspaceUpdateRequest
from kdp_api.model.workspaces_subscription import WorkspacesSubscription
from kdp_api.model.workspaces_subscription_subscription_item_ids import WorkspacesSubscriptionSubscriptionItemIds
from kdp_api.model.write_batch_response import WriteBatchResponse

==> kdp-api-python-client-4.57.0.tar.gz: kdp-api-python-client-4.57.0/kdp_api/models/__init__.py <==
# flake8: noqa

# import all models into this package
# if you have many models here with many references from one model to another this may
# raise a RecursionError
# to avoid this, import only the models that you directly need like:
# from from kdp_api.model.pet import Pet
# or import this package, but before doing it, use:
# import sys
# sys.setrecursionlimit(n)

from kdp_api.model.abac_label_parser_paginator import AbacLabelParserPaginator
from kdp_api.model.abac_label_parsers import AbacLabelParsers
from kdp_api.model.abac_label_parsers_list import AbacLabelParsersList
from kdp_api.model.api_error import ApiError
from kdp_api.model.application import Application
from kdp_api.model.application_create_request import ApplicationCreateRequest
from kdp_api.model.application_list import ApplicationList
from kdp_api.model.application_paginator import ApplicationPaginator
from kdp_api.model.application_patch_request import ApplicationPatchRequest
from kdp_api.model.application_required_dataset_access import ApplicationRequiredDatasetAccess
from kdp_api.model.application_update_request import ApplicationUpdateRequest
from kdp_api.model.applications_required_dataset_access import ApplicationsRequiredDatasetAccess
from kdp_api.model.attribute import Attribute
from kdp_api.model.attribute_assignment import AttributeAssignment
from kdp_api.model.attribute_assignment_create_request import AttributeAssignmentCreateRequest
from kdp_api.model.attribute_assignment_list import AttributeAssignmentList
from kdp_api.model.attribute_assignment_paginator import AttributeAssignmentPaginator
from kdp_api.model.attribute_assignment_patch_request import AttributeAssignmentPatchRequest
from kdp_api.model.attribute_assignment_update_request import AttributeAssignmentUpdateRequest
from kdp_api.model.attribute_create_request import AttributeCreateRequest
from kdp_api.model.attribute_list import AttributeList
from kdp_api.model.attribute_paginator import AttributePaginator
from kdp_api.model.attribute_patch_request import AttributePatchRequest
from kdp_api.model.attribute_update_request import AttributeUpdateRequest
from kdp_api.model.audit_log_configuration import AuditLogConfiguration
from kdp_api.model.audit_log_configuration_list import AuditLogConfigurationList
from kdp_api.model.audit_log_configuration_paginator import AuditLogConfigurationPaginator
from kdp_api.model.audit_log_event import AuditLogEvent
from kdp_api.model.audit_log_event_list import AuditLogEventList
from kdp_api.model.audit_log_paginator import AuditLogPaginator
from kdp_api.model.authentication import Authentication
from kdp_api.model.authentication_details import AuthenticationDetails
from kdp_api.model.authentication_details_authentication import AuthenticationDetailsAuthentication
from kdp_api.model.authentication_details_authentication_payload import AuthenticationDetailsAuthenticationPayload
from kdp_api.model.authentication_details_user import AuthenticationDetailsUser
from kdp_api.model.authentication_list import AuthenticationList
from kdp_api.model.batch_write_request import BatchWriteRequest
from kdp_api.model.custom_identity_provider import CustomIdentityProvider
from kdp_api.model.custom_identity_provider_list import CustomIdentityProviderList
from kdp_api.model.data_source_params import DataSourceParams
from kdp_api.model.dataset import Dataset
from kdp_api.model.dataset_create_request import DatasetCreateRequest
from kdp_api.model.dataset_current_user_permissions import DatasetCurrentUserPermissions
from kdp_api.model.dataset_list import DatasetList
from kdp_api.model.dataset_paginator import DatasetPaginator
from kdp_api.model.dataset_patch_request import DatasetPatchRequest
from kdp_api.model.dataset_permission import DatasetPermission
from kdp_api.model.dataset_permission_create_request import DatasetPermissionCreateRequest
from kdp_api.model.dataset_permission_list import DatasetPermissionList
from kdp_api.model.dataset_permission_paginator import DatasetPermissionPaginator
from kdp_api.model.dataset_permission_patch_request import DatasetPermissionPatchRequest
from kdp_api.model.dataset_permission_update_request import DatasetPermissionUpdateRequest
from kdp_api.model.dataset_update_request import DatasetUpdateRequest
from kdp_api.model.error_code import ErrorCode
from kdp_api.model.group import Group
from kdp_api.model.group_create_request import GroupCreateRequest
from kdp_api.model.group_list import GroupList
from kdp_api.model.group_membership import GroupMembership
from kdp_api.model.group_membership_create_request import GroupMembershipCreateRequest
from kdp_api.model.group_membership_list import GroupMembershipList
from kdp_api.model.group_membership_paginator import GroupMembershipPaginator
from kdp_api.model.group_membership_patch_request import GroupMembershipPatchRequest
from kdp_api.model.group_membership_update_request import GroupMembershipUpdateRequest
from kdp_api.model.group_paginator import GroupPaginator
from kdp_api.model.group_patch_request import GroupPatchRequest
from kdp_api.model.group_update_request import GroupUpdateRequest
from kdp_api.model.index import Index
from kdp_api.model.index_list import IndexList
from kdp_api.model.index_paginator import IndexPaginator
from kdp_api.model.ingest_create_request import IngestCreateRequest
from kdp_api.model.job import Job
from kdp_api.model.job_list import JobList
from kdp_api.model.job_paginator import JobPaginator
from kdp_api.model.json_record import JsonRecord
from kdp_api.model.keycloak_provider_configuration import KeycloakProviderConfiguration
from kdp_api.model.koverse_document_metadata import KoverseDocumentMetadata
from kdp_api.model.lucene_query_request import LuceneQueryRequest
from kdp_api.model.query import Query
from kdp_api.model.query_datasets_summary import QueryDatasetsSummary
from kdp_api.model.query_datasets_summary_datasets import QueryDatasetsSummaryDatasets
from kdp_api.model.query_datasets_summary_request import QueryDatasetsSummaryRequest
from kdp_api.model.query_document_lucene_request import QueryDocumentLuceneRequest
from kdp_api.model.query_document_lucene_response import QueryDocumentLuceneResponse
from kdp_api.model.query_document_lucene_response_records import QueryDocumentLuceneResponseRecords
from kdp_api.model.read_range_request import ReadRangeRequest
from kdp_api.model.record_batch import RecordBatch
from kdp_api.model.reindex_request import ReindexRequest
from kdp_api.model.security_label_info_params import SecurityLabelInfoParams
from kdp_api.model.segment import Segment
from kdp_api.model.segment_list import SegmentList
from kdp_api.model.segment_paginator import SegmentPaginator
from kdp_api.model.sequence_read_request import SequenceReadRequest
from kdp_api.model.source_types import SourceTypes
from kdp_api.model.source_types_list import SourceTypesList
from kdp_api.model.split_points import SplitPoints
from kdp_api.model.stripe_latest_charge import StripeLatestCharge
from kdp_api.model.stripe_latest_charge1 import StripeLatestCharge1
from kdp_api.model.transfer_resource_request import TransferResourceRequest
from kdp_api.model.transfer_resource_request_list import TransferResourceRequestList
from kdp_api.model.user import User
from kdp_api.model.user_create_request import UserCreateRequest
from kdp_api.model.user_list import UserList
from kdp_api.model.user_paginator import UserPaginator
from kdp_api.model.user_patch_request import UserPatchRequest
from kdp_api.model.user_update_request import UserUpdateRequest
from kdp_api.model.workspace import Workspace
from kdp_api.model.workspace_create_request import WorkspaceCreateRequest
from kdp_api.model.workspace_list import WorkspaceList
from kdp_api.model.workspace_paginator import WorkspacePaginator
from kdp_api.model.workspace_patch_request import WorkspacePatchRequest
from kdp_api.model.workspace_subscription import WorkspaceSubscription
from kdp_api.model.workspace_subscription_subscription_item_ids import WorkspaceSubscriptionSubscriptionItemIds
from kdp_api.model.workspace_update_request import WorkspaceUpdateRequest
from kdp_api.model.workspaces_subscription import WorkspacesSubscription
from kdp_api.model.workspaces_subscription_subscription_item_ids import WorkspacesSubscriptionSubscriptionItemIds
from kdp_api.model.write_batch_response import WriteBatchResponse
